==> sparkpipelineframework-1.0.99-py3-none-any.whl: spark_pipeline_framework/transformers/fhir_exporter/v1/test/test_fhir_exporter.py <==
from os import path, makedirs
from pathlib import Path
from shutil import rmtree
from typing import cast

from pyspark.sql import SparkSession, DataFrame
from pyspark.sql.types import StructType
from spark_fhir_schemas.r4.resources.patient import PatientSchema

from spark_pipeline_framework.progress_logger.progress_logger import ProgressLogger
from spark_pipeline_framework.transformers.fhir_exporter.v1.fhir_exporter import (
    FhirExporter,
)


def test_fhir_exporter(spark_session: SparkSession) -> None:
    # Arrange
    data_dir: Path = Path(__file__).parent.joinpath("./")

    temp_folder = data_dir.joinpath("./temp")
    if path.isdir(temp_folder):
        rmtree(temp_folder)
    makedirs(temp_folder)

    fhir_data = data_dir.joinpath("fhir_calls").joinpath("patient")
    df: DataFrame = (
        spark_session.read.schema(cast(StructType, PatientSchema.get_schema()))
        .format("json")
        .option("multiLine", True)
        .load(str(fhir_data))
    )

    df.show(truncate=False)

    df.createOrReplaceTempView("source")

    # Act
    with ProgressLogger() as progress_logger:
        FhirExporter(
            progress_logger=progress_logger,
            view="source",
            file_path=str(temp_folder.joinpath("out")),
        ).transform(df)

    # Assert
    result_df: DataFrame = (
        spark_session.read.schema(cast(StructType, PatientSchema.get_schema()))
        .format("json")
        .option("multiLine", True)
        .load(str(temp_folder.joinpath("out")))
    )

    assert result_df.count() == 2

==> sparkpipelineframework-3.0.70-py3-none-any.whl: spark_pipeline_framework/transformers/fhir_exporter/v1/test/test_fhir_exporter.py <==
from os import path, makedirs
from pathlib import Path
from shutil import rmtree
from typing import cast

from pyspark.sql import SparkSession, DataFrame
from pyspark.sql.types import StructType
from spark_fhir_schemas.r4.resources.patient import PatientSchema

from helixcore.progress_logger.progress_logger import ProgressLogger
from spark_pipeline_framework.transformers.fhir_exporter.v1.fhir_exporter import (
    FhirExporter,
)


def test_fhir_exporter(spark_session: SparkSession) -> None:
    # Arrange
    data_dir: Path = Path(__file__).parent.joinpath("./")

    temp_folder = data_dir.joinpath("./temp")
    if path.isdir(temp_folder):
        rmtree(temp_folder)
    makedirs(temp_folder)

    fhir_data = data_dir.joinpath("fhir_calls").joinpath("patient")
    df: DataFrame = (
        spark_session.read.schema(cast(StructType, PatientSchema.get_schema()))
        .format("json")
        .option("multiLine", True)
        .load(str(fhir_data))
    )

    df.show(truncate=False)

    df.createOrReplaceTempView("source")

    # Act
    with ProgressLogger() as progress_logger:
        FhirExporter(
            progress_logger=progress_logger,
            view="source",
            file_path=str(temp_folder.joinpath("out")),
        ).transform(df)

    # Assert
    result_df: DataFrame = (
        spark_session.read.schema(cast(StructType, PatientSchema.get_schema()))
        .format("json")
        .option("multiLine", True)
        .load(str(temp_folder.joinpath("out")))
    )

    assert result_df.count() == 2
